%mx_ss.m
% 
% Modified by David Torun, for International Macroeconomics, FS 2019
% --> Calibrated for Small Open Economies (ALFA, OMEGA, SX, SYX, STB, RSTAR)
% 
%Steady state of the MX model  as presented in  chapter 7 of ``Open Economy Macroeconomics,''
%by Martin Uribe and Stephanie Schmitt-Grohe.
% Martn Uribe and Stephanie Schmitt-Groh, 2014. 

%Calibration
%The calibration is described in Section 7.6
%Time unit is a year
% taken from Uribe & Schmitt-Groh Chapter 7
SIGG = 2; %
% MUPARAM = 1; %Elasticity of Substitution between importables and exportables; 
TFP_M = 1; %Level of technology in M sector; 
TOTBAR = 1;% terms of trade in AR(1) 
DELTA = 0.1; %depreciation rate

% No risk premium for Small Open Economies (industrialized)
RSTAR = 0.04; %long-run interest rate -> no risk premium here!
BETTA = 1/(1+RSTAR); %subjective discount factor
% -> PBAR seems to be already included in RSTAR! --> otherwise we'd need to
% add it (page 241)

% from 
OMEGA = 1.455; %Frisch ela st. 
ALFA =0.32;% capital share 

% from data: --> see Stata file "Section_7_merge_trade_gross_and_va_with_gdp.do"
SX = 0.3196319; %Export share in GDP. --> for Small Open Economies according to "select_small_open_economies.do"
% from data: --> see Stata file "Section_7_merge_trade_gross_and_va_with_gdp.do"
STB = -0.01; %Steady state trade balance to output ratio.

% from data: --> see Stata file "Section_7_gdp_shares_agr_ind_serv.do"
SYX = 0.5180818; %share of exportable output in GDP (see Section 7.6.5)
GAMA = SYX /(1-SYX); %GDP in X sector over GDP in M sector. -> by definition

% % % Start using the equilibrium conditions;
tot = TOTBAR; 
um = 1/BETTA - 1 + DELTA; %equation (7.17) in SS
ux = 1/BETTA -1 + DELTA;  %equation (7.18) in SS -> same as above! -> see also text on page 235

%intermediate variables, all are ratios of x over m
A = GAMA^((1-ALFA)*(OMEGA-1)/OMEGA)/TOTBAR; %A_x/A_m
% % % --> ???

tfp_m = TFP_M;
tfp_x = A*tfp_m; 
TFP_X = tfp_x;  %A_x

UPSILON = (SYX -SX) / (1/(1+GAMA) +SX-STB); 
%see Upsilon on page 242
UPSILON_tot = (UPSILON*tot^(MUPARAM-1))^(-1/MUPARAM);
CHI = UPSILON_tot/(1+UPSILON_tot);
%see Chi on page 242

OMEGAM = OMEGA; 
OMEGAX = OMEGA; 
ALFAX = ALFA; 
ALFAM = ALFA; 
% same alpha and omega for both sectors

ax_o_am = (CHI/(1-CHI) * tot)^(-MUPARAM); 
% a^x / a^m as defined in equation (7.35)
if MUPARAM==1
pm = CHI*ax_o_am^(1-CHI);
% eqatuion (7.19): p_t^m = A_1(a^m,a^x) for mu=1
else
pm = ( CHI  + (1-CHI)*ax_o_am^(1-1/MUPARAM))^(1/(1-1/MUPARAM) -1) * CHI ;
end
px = tot* pm; %use definition of tot to get px


km_o_hm  = (um/pm/ ALFA/tfp_m)^(1/(ALFA-1)); 
% use (7.23) and plug in functional form
wm =  pm*(1-ALFA)*tfp_m *km_o_hm^(ALFA); 
% use (7.24) and plug in functional form
 
kapx_o_hx  = (ux/px/ ALFA/tfp_x)^(1/(ALFA-1)); 
% use (7.25) and plug in functional form
wx = tfp_x*px* (1-ALFA)*kapx_o_hx^(ALFA); 
% use (7.26) and plug in functional form

hm = wm^(1/(OMEGA-1)); 
% using (7.13) and (7.14) as well as utility functional form
hx = wx^(1/(OMEGA-1)); 
% using (7.13) and (7.15) as well as utility functional form

kapx = hx *kapx_o_hx; 
% by definition
km = hm * km_o_hm; 
% by definition

ym = tfp_m * km^ALFA * hm^(1-ALFA); 
% by definition
yx = tfp_x * kapx^ALFA * hx^(1-ALFA); 
% by definition
im = DELTA * km; 
% using (7.11) in SS (k constant)
ix = DELTA * kapx; 
% using (7.12) in SS (k constant)
ivv = im + ix; 
% total investment
y = px*yx+pm*ym; 
% total output
r = RSTAR; %interest rate
% -> can probably do this because RSTAR=0.11 --> otherwise we'd need to set
% RSTAR = 0.04 but PBAR = 0.07 in equation 21 in mx_model.m !!!
d = STB * y * (1+r) /r; 
% -> use eq. (7.30) in SS and solve for d; use tb/y * y as in Chapter 4
DBAR=d; %debt

m = y*(SX-STB); 
% by definition
am = ym + m/pm; 
% home absorption of import good
x =  SX*y;
% by definition
ax = yx - x/px; 
% home absorption of export good

% Using (7.27) in SS we get consumption in SS:
if MUPARAM==1
c = am^CHI*ax^(1-CHI) - im - ix;
else
c =  ( CHI * am^(1-1/MUPARAM)  + (1-CHI)*ax^(1-1/MUPARAM) )^(1/(1-1/MUPARAM)) -   im - ix; 
end

la = [c - hm^OMEGA/OMEGA - hx^OMEGA/OMEGA]^(-SIGG);
% plugg utility into (7.13)
output = y;
% definition
tby = (x-m)/output; 
% definition
OUTPUT = output; 

TOT = tot;

h_x = hx;  clear hx 

output_constant_prices = output; 
% in SS we have constant prices!
c_constant_prices = c; 

ivv_constant_prices = ivv;

tby_constant_prices = tby;

PX = px; 

PM = pm; 

save mx_ss.mat SIGG OMEGA ALFA RSTAR TFP_M TOTBAR DELTA CHI TFP_X DBAR MUPARAM externallyset_parameters 